%define anolis_release 1

# There are cicular build dependencies between aiohttp and gunicorn,
# Bootstraping gunicorn without tests is needed.
%bcond_without tests

%global srcname gunicorn
%global _description %{expand:
Gunicorn 'Green Unicorn' is a Python WSGI HTTP Server for UNIX. It is a
pre-fork worker model. The Gunicorn server is broadly compatible with various
web frameworks, simply implemented, light on server resources, and fairly
speedy.}

Name:           python-%{srcname}
Version:        22.0.0
Release:        %{anolis_release}%{?dist}
Summary:        Python WSGI HTTP Server
License:        MIT
URL:            https://gunicorn.org/
Source:         %pypi_source %{srcname}
# distro-specific, not upstreamable
Patch:          0001-use-dev-log-for-syslog.patch
BuildArch:      noarch

BuildRequires: python3-pytest-cov

%description %{_description}

%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel

%description -n python3-%{srcname} %{_description}

%package -n python3-%{srcname}-doc
Summary:        Documentation for the %{name} package
BuildRequires:  make

%description -n python3-%{srcname}-doc
Documentation for the %{name} package.

%prep
%autosetup -n %{srcname}-%{version} -p 1
# disable code coverage checks
sed -e '/coverage/d' -e '/pytest-cov/d' -i requirements_test.txt
%if %{without tests}
sed -e '/aiohttp/d' -i requirements_test.txt
%endif
sed -e '/addopts/d' -i setup.cfg

%generate_buildrequires
%pyproject_buildrequires requirements_dev.txt

%build
%pyproject_wheel
%make_build -C docs html

%install
%pyproject_install
%pyproject_save_files %{srcname}
# symlink extra executable names
ln -s %{_bindir}/gunicorn %{buildroot}%{_bindir}/gunicorn-3
ln -s %{_bindir}/gunicorn %{buildroot}%{_bindir}/gunicorn-%{python3_version}

%if %{with tests}
%check
%pytest --verbose tests
%endif

%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE
%{_bindir}/%{srcname}
%{_bindir}/%{srcname}-3
%{_bindir}/%{srcname}-%{python3_version}

%files -n python3-%{srcname}-doc
%doc NOTICE README.rst THANKS
%doc docs/build/html/*

%changelog
* Sat May 11 2024 mgb01105731 <mgb01105731@alibaba-inc.com> - 22.0.0-1
- update to 22.0.0

* Wed Mar 27 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 20.1.0-4
- Build with tests

* Wed Mar 27 2024 Zhao Hang <wb-zh951434@alibaba-inc.com> - 20.1.0-3
- Rebuild with python3.11

* Sun May 07 2023 Funda Wang <fundawang@yeah.net> - 20.1.0-2
- Build with tests

* Fri May 05 2023 Funda Wang <fundawang@yeah.net> - 20.1.0-1
- Import package for anolis 23
